@@ -10,6 +10,8 @@ def doit1(x):
 #    x = [i*i for i in range(1,1000)][0]
     y = 1
 #    w, v = LA.eig(np.diag(arr)) # (1, 2, 3, 4, 5, 6, 7, 8, 9, 10)))
+    x = [i*i for i in range(0,100000)][99999]
+
     x = [i*i for i in range(0,100000)][99999]
     y1 = [i*i for i in range(0,200000)][199999]
     z1 = [i for i in range(0,300000)][299999]
@@ -46,13 +48,14 @@ def doit3(x):
 def stuff():
     y = np.random.randint(1, 100, size=5000000)[4999999]
     x = 1.01
-    for i in range(1,10):
-        for j in range(1,10):
+    for i in range(1):
+        for j in range(1):
             x = doit1(x)
             x = doit2(x)
             x = doit3(x)
             x = 1.01
     return x
 
+#doit1(1.01)
 stuff()
 
